/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha;

import com.twiddles.ganesha.gui.*;
import java.io.*;

/**
  This class is intended to be run by users in order to start up the Ganesha application.

   @author James Nash
*/
public class Ganesha{
    /**
	The version number of this release of Ganesha. 
    */	
    public static final int MAJOR_VERSION = 1;

    /**
	The sub-version number of this release of Ganesha. 
    */	
    public static final int MINOR_VERSION = 0;

    /**
        Performs the initialisation of the Ganesha application.
	This method checks that the Java version is > 1.4 and warns the user
	if that is not the case. Then it attempts to lauch the Ganesha GUI by
	constructing a {@link com.twiddles.ganesha.gui.GUI} object and calling it's show() method.
	If this fails (for example on a headless machine) a user friendly
	error message is displayed before exiting.

	@param args if the first argument is a filename that file will be opened
	@see com.twiddles.ganesha.gui.GUI
    */
    public static void main(String[] args){

	// some initial checks to see that we can run
	
	// check java version (Ganesha has been developed using Java 1.4, so anything
        // less could be dodgy!
        
        // get version
        String version = System.getProperty("java.version") ;
        //extract major version
        int firstDot = version.indexOf('.');
        int major = Integer.parseInt( version.substring(0, firstDot) );
        //extract minor version
        firstDot++;
        int minor = Integer.parseInt( version.substring(firstDot , version.indexOf('.', firstDot)) );
        
        // check if it's lower than 1.4
        if ( ((major == 1) && (minor < 4)) || (major < 1) ){
            // untested!!
            System.err.println("WARNING: You are using a version of Java older than 1.4! Ganesha has not been tested under these conditions and may not function properly.");
        }
            
        
	// ok we can run!


        // (try to) start Ganesha
        try{
            GUI gui = new GUI();
            gui.show();

	    // were we given a file to open?
	    if ( args.length != 0 ){
		File input = new File( args[0] );
		
		// try to open it. (the GUI will deal with any potential errors!)
		gui.openFile( input );
	    }


	}
        catch( InternalError e ){
            // in the unlikely event that the user attempts to start Ganesha on a system that
            // doesn't support GUIs (perhaps an ssh connection to a box without X-forwarding)
            // this will print out a more useful message than the standard java exception blurb!
            System.err.print("ERROR: Ganesha failed to start due to an internal Java error: ");
            System.err.println( e.getMessage() );
        }
    
    }


}
