/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha.functionality;

import com.hp.hpl.jena.rdf.model.*;
import com.hp.hpl.jena.vocabulary.*;
import java.util.*;
/**
   Implementation of {@link RDFAlt} using Jena.
   <p>
   This requires the <a href="http://jena.sourceforge.net/">Jena API</a>
   to be installed on your system and listed in java's CLASSPATH.

   @see JenaSeq
   @see JenaAlt
   @author James Nash
*/
public class JenaAlt extends JenaContainerAdaptor implements RDFAlt{

    /**
       Constructs a new JenaAlt.

       @param alt the Jena API Alt object to use
    */
    public JenaAlt(Alt alt){
	super(alt);
    }


    /**
       Removes the object at the specified position from this alt.
       Note that this will probably change the ordering of objects.
       Thus, when deleting the first ie. default object there is
       no guarantee about what will become the new default!

       @param index the index of the element to be deleted.
    */
    public void removeObject(int index){

	// convert container to Jena Alt
	Alt alt = (Alt) con;

	Statement deleteMe = alt.getProperty( RDF.li(index) );

	alt.remove( deleteMe );

    }

    /**
       Makes the specified object the default one.

       @param index index of the object that should be made default
    */
    public void setDefault(int index){

	// bypass Jena's Alt interface and just
	// swap element at index with element at 1
	// VERY DIRTY!! sorry!

	if( index != 1 ){

	    Statement from = con.getProperty( RDF.li(1) );
	    Statement to = con.getProperty( RDF.li(index) );

	    // swap objects
	    RDFNode fromNode = from.getObject();
	    from.changeObject( to.getObject() );	    
	    to.changeObject( fromNode );

	}
	// else: 1 is already default so no work would need to be done!
	
    }

    /**
       Returns the index of the default object.

       @return default object's index
    */
    public int getDefault(){

	// this need more work!!!!
	// it fucks up if the default is changed!

	// the rdf:_1 element is always the default...
	return 1;
    }


}
