/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha.functionality;

import com.hp.hpl.jena.rdf.model.*;
/**
   Implementation of {@link RDFPredicate} using Jena.
   <p>
   This requires the <a href="http://jena.sourceforge.net/">Jena API</a>
   to be installed on your system and listed in java's CLASSPATH.

   @author James Nash
*/
public class JenaPredicate implements RDFPredicate{

    /**
       The Jena API Property being wrapped by this class.
    */
    private Property prop;
    
    /**
       Descriptive text about this property.
    */
    private String descr;

    /**
       Constructs a new JenaPredicate from a Jena API Property object.
    */
    public JenaPredicate(Property prop){

	this.prop = prop;

	// get short version of URI to use a description
	this.descr = JenaFile.shorten( prop.getURI() );

    }



    /**
       Gets the type of this property.
       Usually a URI of some kind.

       @return type of property
    */
    public String getType(){
	return prop.getURI();
    }

    /**
       Gets brief descriptive name for this property.

       @return short description
    */
    public String getDescr(){
	return descr;
    }


    /**
       Retrieves the Jena API Property that is behind this property.

       @return Jena API Property
    */
    public Property getJenaProp(){
	return prop;
    }


}
