/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha.gui;

import javax.swing.*;
import com.twiddles.ganesha.gui.gfx.*;
/**
   The toolbar for the main app window.
   This is a detachable toolbar which is initially placed
   towards the top of the GUI, just beneath the menubar.
   All the buttons of the toolbar and their functionality
   are defined in this class.

   @author James Nash
*/
class GToolbar extends JToolBar{

    /**
       Reference to the main app window that contains this toolbar
    */
    private final GUI window;



    // toolbar buttons
    private JButton newFile;
    private JButton openFile;
    private JButton saveFile;
    private JButton saveFileAs;

    // can we use the save button?
    private boolean saveEnabled;

    /**
       Constructs a fully-functional toolbar.

       @param window the main app window that will contain the toolbar
    */
    public GToolbar( GUI window ){
	super("Ganesha Toolbar");

	this.window = window;


       	// create toolbar....

	// new button
	newFile = new JButton( GUIIcons.getIcon( GUIIcons.NEW_ICON ) );
	newFile.setToolTipText("New");
	newFile.addActionListener(new GUIEvent(window, GUIEvent.NEW_FILE));
	this.add( newFile );
  
	// open button
	openFile = new JButton( GUIIcons.getIcon( GUIIcons.OPEN_ICON ) );
	openFile.setToolTipText("Open");
	openFile.addActionListener(new GUIEvent(window, GUIEvent.OPEN_FILE));
	this.add( openFile );
  
	// save button
	saveFile = new JButton( GUIIcons.getIcon( GUIIcons.SAVE_ICON ) );
	saveFile.setToolTipText("Save");
	saveFile.addActionListener(new GUIEvent(window, GUIEvent.SAVE_FILE));
	this.add( saveFile );
  
	// save as button
	saveFileAs = new JButton( GUIIcons.getIcon( GUIIcons.SAVE_AS_ICON ) );
	saveFileAs.setToolTipText("Save As");
	saveFileAs.addActionListener(new GUIEvent(window, GUIEvent.SAVE_FILE_AS));
	this.add( saveFileAs );


	this.addSeparator();
       
	    	
    }



    /**
       Enable or disable buttons that are effected by the file (not) have being changed.

       @param edited whether or not the loaded file has been edited
     */
    public void editedUpdate(boolean edited){


	// save button depends on save enable too
	saveFile.setEnabled( saveEnabled && edited );

    }


    /**
       Enable or disable buttons that are effected by the file (not) have being loaded.

       @param loaded whether or not the loaded file has been loaded
     */
    public void loadedUpdate(boolean loaded){

	saveFile.setEnabled( loaded );
	saveFileAs.setEnabled( loaded );

    }


    /**
       Enable or disable the save button. Use to prevent the user trying
       to save read-only files. ( 'save as' is unaffected by this ) 

       @param enabled should the 'Save' option be enabled or not
    */
    public void setSaveEnable(boolean enabled){

	saveEnabled = enabled;

	saveFile.setEnabled( saveEnabled );

    }



}
