/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha.gui;

import javax.swing.*;
import com.twiddles.ganesha.functionality.*;
/**
   Functionality for editing values in an Object table.

   @author James Nash
*/
class ObjectEditor{

    /**
        Open the correct kind of editing window for the object.
    
	@param jt the PropertyTable being modified
        @param row the row the cell to be edited is in
	@param col the column the cell to be edited is in
    */
    public static void editObject(ResourceList resList, JInternalFrame win, JTable jt, int row, int col){

	// want to get the property out of the table
        ObjectTable ot = (ObjectTable) jt.getModel();


        RDFObject obj = ot.getObjectAt(row);


        if ( obj.getObjType() == RDFObject.LITERAL ){
            // literal value
            //System.out.println("Want to edit literal value");
            String newVal = resList.editLiteral(win, obj);
        
            if ( newVal != null ){
                // the user changed the value
                //System.out.println("Setting new literal value");
                jt.setValueAt( newVal, row, col );
            }
            
        }
        else if ( obj.getObjType() == RDFObject.RESOURCE ){
            // it's a resource
            RDFResource res = obj.getResource();
            ResourceListEntry resEnt = resList.findResource( res );
            if ( resEnt == null ){
                //System.out.println("Want to edit undescribed resource");
		RDFObject newVal = resList.editResource(win, obj);
        
		if ( newVal != null ){
		    // the user changed the value
		    //System.out.println("Setting new literal value");
		    jt.setValueAt( newVal, row, col );
		}



            }
            else{
                resEnt.showWindow();
            }
            
        }
        else if ( obj.getObjType() == RDFObject.BAG ){
            // it's a bag
            resList.showContainerWindow( obj.getBag() );
        }
        else if ( obj.getObjType() == RDFObject.SEQ ){
            // it's a bag
            resList.showContainerWindow( obj.getSeq() );
        }
        else if ( obj.getObjType() == RDFObject.ALT ){
            // it's a bag
            resList.showContainerWindow( obj.getAlt() );
        }

	

    }





}

