/*
    Copyright 2004 James Nash
                                                                                                
    This file is part of Ganesha.
                                                                                                
    Ganesha is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
                                                                                                
    Ganesha is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
                                                                                                
    You should have received a copy of the GNU General Public License
    along with Ganesha (see the LICENSE file); if not, write to the Free
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA  02111-1307  USA
                                                                                                
*/
package com.twiddles.ganesha.gui.gfx;

import javax.swing.*;
import java.util.*;

/**
    Provides access to various icons used in the GUI.
    Mostly bitmap icons for buttons and such.
    
    @author James Nash
*/
public class GUIIcons {

    // the available icons...

    /**
       "Window is open" icon
    */
    public static final int WINDOW_OPEN_ICON = 0;


    /**
       "Window is iconified" icon
    */
    public static final int WINDOW_ICONIFIED_ICON = 1;

    
    /**
       "Window is closed" icon
    */
    public static final int WINDOW_CLOSED_ICON = 2;

    /**
       "Add resource" icon
    */
    public static final int ADD_RESOURCE_ICON = 3;

    /**
       "Remove resource" icon
    */
    public static final int REMOVE_RESOURCE_ICON = 4;


    /**
       "Open" icon
    */
    public static final int OPEN_ICON = 5;

    /**
       small "Open" icon
    */
    public static final int MINI_OPEN_ICON = 6;


    /**
       "New" icon
    */
    public static final int NEW_ICON = 7;

    /**
       small "New" icon
    */
    public static final int MINI_NEW_ICON = 8;

    /**
       "Save" icon
    */
    public static final int SAVE_ICON = 9;

    /**
       small "Save" icon
    */
    public static final int MINI_SAVE_ICON = 10;

    /**
       "Save As" icon
    */
    public static final int SAVE_AS_ICON = 11;

    /**
       small "Save As" icon
    */
    public static final int MINI_SAVE_AS_ICON = 12;

    /**
       "Edit resource" icon
    */
    public static final int EDIT_RESOURCE_ICON = 13;

    /**
       small "Add resource" icon
    */
    public static final int MINI_ADD_RESOURCE_ICON = 14;

    /**
       small "Remove resource" icon
    */
    public static final int MINI_REMOVE_RESOURCE_ICON = 15;

    /**
       small "Edit resource" icon
    */
    public static final int MINI_EDIT_RESOURCE_ICON = 16;

    /**
       small "Bag container" icon
    */
    public static final int MINI_BAG_ICON = 17;

    /**
       small "Seq container" icon
    */
    public static final int MINI_SEQ_ICON = 18;

    /**
       small "Alt container" icon
    */
    public static final int MINI_ALT_ICON = 19;

    /**
       small "Literal value" icon
    */
    public static final int MINI_LITERAL_ICON = 20;

    /**
       small "Unknown value type" icon
    */
    public static final int MINI_UNKNOWN_ICON = 21;


    /**
       small "Add property" icon
    */
    public static final int ADD_PROPERTY_ICON = 22;


    /**
       small "Remove property" icon
    */
    public static final int REMOVE_PROPERTY_ICON = 23;


    /**
       small "Edit property" icon
    */
    public static final int EDIT_PROPERTY_ICON = 24;


    /**
       small app icon
    */
    public static final int MINI_GANESHA_ICON = 25;


    /**
       small forward icon
    */
    public static final int MINI_FORWARD_ICON = 26;


    /**
       small back icon
    */
    public static final int MINI_BACK_ICON = 27;


    /**
       small finish icon
    */
    public static final int MINI_FINISH_ICON = 28;


    /**
       small 'new resource tpye' icon
    */
    public static final int MINI_NEW_RES_TYPE_ICON = 29;


    /**
       small 'new property type' icon
    */
    public static final int MINI_NEW_PROP_TYPE_ICON = 30;


    /**
       'move object forward in a sequence' icon
    */
    public static final int MOVE_OBJ_UP_ICON = 31;


    /**
       'move object back in a sequence' icon
    */
    public static final int MOVE_OBJ_DOWN_ICON = 32;


    /**
       'make object default of alt' icon
    */
    public static final int MAKE_OBJ_DEF_ICON = 33;


    /**
       fancy Ganesha pic :)
    */
    public static final int SPLASH_PIC = 34;




    /**
       Returns the specified bitmap icon.

       @param iconType the icon to fetch
       @return the requested GUI icon
    */
    public static ImageIcon getIcon( int iconType ){
	
	//file name of icon
	String filename = null;
	String description = "";

	switch( iconType ){

	case WINDOW_OPEN_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/WindowOpen16.gif";
	    description = "This resource is currently open in a window";
	    break;

	case WINDOW_ICONIFIED_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/WindowIcon16.gif";
	    description = "This resource's window is currently iconified";
	    break; 

	case WINDOW_CLOSED_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/WindowClosed16.gif";
	    description = "This resource is currently NOT open in any window.";
	    break;

	case ADD_RESOURCE_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/AddResource24.gif";
	    description = "Add Resource";
	    break;

	case REMOVE_RESOURCE_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/RemoveResource24.gif";
	    description = "Remove Resource";
	    break;

	case EDIT_RESOURCE_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/EditResource24.gif";
	    description = "Edit Resource";
	    break;



	case MINI_ADD_RESOURCE_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/AddResource16.gif";
	    description = "Add Resource";
	    break;

	case MINI_REMOVE_RESOURCE_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/RemoveResource16.gif";
	    description = "Remove Resource";
	    break;

	case MINI_EDIT_RESOURCE_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/EditResource16.gif";
	    description = "Edit Resource";
	    break;



	case OPEN_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/Open24.gif";
	    description = "Open file";
	    break;

	case MINI_OPEN_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/Open16.gif";
	    description = "Open file";
	    break;

	case NEW_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/New24.gif";
	    description = "Create new file";
	    break;

	case MINI_NEW_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/New16.gif";
	    description = "Create new file";
	    break;

	case SAVE_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/Save24.gif";
	    description = "Save current work";
	    break;

	case MINI_SAVE_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/Save16.gif";
	    description = "Save current work";
	    break;

	case SAVE_AS_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/SaveAs24.gif";
	    description = "Save current work to another file";
	    break;

	case MINI_SAVE_AS_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/SaveAs16.gif";
	    description = "Save current work to another file";
	    break;


	case MINI_BAG_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/Bag16.gif";
	    description = "Bag container";
	    break;  

	case MINI_SEQ_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/Seq16.gif";
	    description = "Sequence container";
	    break;  

	case MINI_ALT_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/Alt16.gif";
	    description = "Alternatives container";
	    break;  

	case MINI_LITERAL_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/Literal16.gif";
	    description = "Literal value";
	    break;  

	case MINI_UNKNOWN_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/Unknown16.gif";
	    description = "Unknown value type";
	    break;

	case ADD_PROPERTY_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/AddProperty24.gif";
	    description = "Add a new property";
	    break;

	case REMOVE_PROPERTY_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/RemoveProperty24.gif";
	    description = "Remove selected properties";
	    break; 

	case EDIT_PROPERTY_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/EditProperty24.gif";
	    description = "Edit the selected property";
	    break;   

	case MINI_GANESHA_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/GaneshaIcon16.gif";
	    description = "Ganesha application icon";
	    break;


	case MINI_FORWARD_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/Forward16.gif";
	    description = "forward icon";
	    break;


	case MINI_BACK_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/Back16.gif";
	    description = "back icon";
	    break;


	case MINI_FINISH_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/Finish16.gif";
	    description = "Finish icon";
	    break;


	case MINI_NEW_RES_TYPE_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/NewResourceType16.gif";
	    description = "New resource type icon";
	    break;


	case MINI_NEW_PROP_TYPE_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/NewPropertyType16.gif";
	    description = "New property type icon";
	    break;


	case MOVE_OBJ_UP_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/MoveObjectUp24.gif";
	    description = "Move an object forward a position in a sequence";
	    break;


	case MOVE_OBJ_DOWN_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/MoveObjectDown24.gif";
	    description = "Move an object back a position in a sequence";
	    break;


	case MAKE_OBJ_DEF_ICON:
	    filename = "/com/twiddles/ganesha/gui/gfx/MakeObjectDefault24.gif";
	    description = "Makes the object the default of the alternatives";
	    break;    

	case SPLASH_PIC:
	    filename = "/com/twiddles/ganesha/gui/gfx/ganesha_splash.png";
	    description = "Fancy Ganesha pic!";
	    break;


	}

	ImageIcon icon = new ImageIcon( GUIIcons.class.getResource(filename), description );
	
	return icon;

    }




}
